@@ -30,8 +30,6 @@ GRPC_SERVER_KEY = "grpc_server"
 GRPC_CLIENT_KEY = "grpc_client"
 
 # Configurations
-DEFAULT_PAYLOADS_ENABLED = True
-MAX_PAYLOAD_SIZE = 128 * 1024
 MAX_WAIT_TIME = 0.1  # seconds
 ALLOWED_EXPORTER_TYPES = [HTTP_EXPORTER_TYPE, GRPC_EXPORTER_TYPE, CONSOLE_EXPORTER_TYPE]
 ALLOWED_CONTENT_TYPES = [
